==> die-engine_3.07.orig.tar.gz: die-engine-3.07/XDemangleWidget/dialogdemangle.cpp <==
/* Copyright (c) 2021-2022 hors<horsicq@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#include "dialogdemangle.h"

#include "ui_dialogdemangle.h"

DialogDemangle::DialogDemangle(QWidget *pParent, QString sString) : XShortcutsDialog(pParent), ui(new Ui::DialogDemangle)
{
    ui->setupUi(this);

    ui->widgetDemangle->setData(sString);
}

DialogDemangle::~DialogDemangle()
{
    delete ui;
}

void DialogDemangle::setData(QString sString)
{
    ui->widgetDemangle->setData(sString);
}

void DialogDemangle::on_pushButton_clicked()
{
    this->close();
}

==> die-engine_3.09.orig.tar.gz: die-engine-3.09/XDemangleWidget/dialogdemangle.cpp <==
/* Copyright (c) 2021-2023 hors<horsicq@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#include "dialogdemangle.h"

#include "ui_dialogdemangle.h"

DialogDemangle::DialogDemangle(QWidget *pParent, const QString &sString) : XShortcutsDialog(pParent), ui(new Ui::DialogDemangle)
{
    ui->setupUi(this);

    ui->widgetDemangle->setData(sString);
}

DialogDemangle::~DialogDemangle()
{
    delete ui;
}

void DialogDemangle::setData(const QString &sString)
{
    ui->widgetDemangle->setData(sString);
}

void DialogDemangle::on_pushButton_clicked()
{
    this->close();
}
